@@ -25,7 +25,8 @@ typedef enum {
     EAV_TLD_INFRASTRUCTURE      = 1 << 6,
     EAV_TLD_SPONSORED           = 1 << 7,
     EAV_TLD_TEST                = 1 << 8,
-    EAV_TLD_SPECIAL             = 1 << 9
+    EAV_TLD_SPECIAL             = 1 << 9,
+    EAV_TLD_RETIRED             = 1 << 10
 } EAV_TLD;
 
 
@@ -121,6 +122,7 @@ enum {
     EEAV_TLD_SPONSORED = 30,
     EEAV_TLD_TEST,
     EEAV_TLD_SPECIAL,
+    EEAV_TLD_RETIRED,
     EEAV_MAX
 };
 
